"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Label = _interopRequireDefault(require("./Label"));
var _Placeholder = _interopRequireDefault(require("./Placeholder"));
var _Underline = _interopRequireDefault(require("./Underline"));
var _ErrorHelper = _interopRequireWildcard(require("./ErrorHelper"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  ..._ErrorHelper.defaultProps,
  marginBottom: 8,
  paddingTop: 20,
  paddingRight: 0,
  paddingBottom: 8,
  paddingLeft: 0,
  color: 'black',
  fontSize: 15,
  fontWeight: 'normal'
};
const Input = (_ref, ref) => {
  let {
    minHeight,
    maxHeight,
    marginTop,
    marginRight,
    marginBottom = defaultProps.marginBottom,
    marginLeft,
    paddingTop = defaultProps.paddingTop,
    paddingRight = defaultProps.paddingRight,
    paddingBottom = defaultProps.paddingBottom,
    paddingLeft = defaultProps.paddingLeft,
    color = defaultProps.color,
    activeColor,
    fontFamily,
    fontSize = defaultProps.fontSize,
    fontWeight = defaultProps.fontWeight,
    label,
    labelDuration,
    labelColor,
    labelActiveTop,
    labelActiveColor,
    labelActiveScale,
    placeholder,
    placeholderColor,
    underlineDuration,
    underlineHeight,
    underlineColor,
    underlineActiveColor,
    underlineActiveHeight,
    error,
    errorColor = _ErrorHelper.defaultProps.errorColor,
    errorPaddingTop,
    errorFontSize,
    ...props
  } = _ref;
  const [value, setValue] = (0, _react.useState)('');
  const [focused, setFocused] = (0, _react.useState)(false);
  const [height, setHeight] = (0, _react.useState)(fontSize * 1.5);
  const getValue = props.value != null ? props.value : value;
  const hasValue = Boolean(getValue && getValue.length > 0);
  const labelProps = {
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    activeColor,
    fontFamily,
    fontSize,
    fontWeight,
    label,
    labelDuration,
    labelColor,
    labelActiveTop,
    labelActiveColor,
    labelActiveScale,
    focused,
    hasValue,
    error,
    errorColor
  };
  const placeholderProps = {
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    fontFamily,
    fontSize,
    fontWeight,
    placeholder,
    placeholderColor,
    focused,
    hasValue
  };
  const underlineProps = {
    activeColor,
    underlineDuration,
    underlineHeight,
    underlineColor,
    underlineActiveColor,
    underlineActiveHeight,
    focused,
    error,
    errorColor
  };
  const containerStyle = {
    marginTop,
    marginRight,
    marginBottom,
    marginLeft
  };
  let getHeight = height;
  if (props.multiline && props.height) {
    // Disable autogrow if height prop
    getHeight = props.height;
  }
  const inputStyle = {
    minHeight,
    maxHeight,
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    color,
    fontFamily,
    fontSize,
    fontWeight,
    textAlign: _reactNative.I18nManager.isRTL ? 'right' : 'left',
    ..._reactNative.Platform.select({
      ios: {
        height: paddingTop + paddingBottom + (props.multiline ? getHeight : fontSize * 1.5)
      },
      android: {
        height: props.multiline ? getHeight : fontSize * 1.5 + paddingTop + paddingBottom,
        textAlignVertical: 'top'
      }
    })
  };
  const errorProps = {
    error,
    errorColor,
    errorPaddingTop,
    errorFontSize
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: containerStyle
  }, /*#__PURE__*/_react.default.createElement(_Label.default, labelProps), placeholder ? /*#__PURE__*/_react.default.createElement(_Placeholder.default, placeholderProps) : null, /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({}, props, {
    ref: ref,
    style: inputStyle,
    underlineColorAndroid: "transparent",
    onFocus: handleFocus,
    onBlur: handleBlur,
    onChangeText: handleChangeText,
    onContentSizeChange: handleContentSizeChange,
    value: getValue
  })), /*#__PURE__*/_react.default.createElement(_Underline.default, underlineProps), error ? /*#__PURE__*/_react.default.createElement(_ErrorHelper.default, errorProps) : null);
  function handleFocus(event) {
    setFocused(true);
    if (typeof props.onFocus === 'function') {
      props.onFocus(event);
    }
  }
  function handleBlur(event) {
    setFocused(false);
    if (typeof props.onBlur === 'function') {
      props.onBlur(event);
    }
  }
  function handleChangeText(text) {
    const {
      value
    } = props;

    // Make support of uncontrolled component
    if (value == null) {
      setValue(text);
    }
    if (typeof props.onChangeText === 'function') {
      props.onChangeText(text);
    }
  }
  function handleContentSizeChange(event) {
    const {
      height
    } = event.nativeEvent.contentSize;
    setHeight(Math.max(fontSize * 1.5, Math.ceil(height)));
    if (typeof props.onContentSizeChange === 'function') {
      props.onContentSizeChange(event);
    }
  }
};
var _default = /*#__PURE__*/_react.default.forwardRef(Input);
exports.default = _default;
//# sourceMappingURL=Input.js.map