function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
import { View, TextInput, Platform, I18nManager } from 'react-native';
import Label from './Label';
import Placeholder from './Placeholder';
import Underline from './Underline';
import ErrorHelper, { defaultProps as errorDefaultProps } from './ErrorHelper';
const defaultProps = {
  ...errorDefaultProps,
  marginBottom: 8,
  paddingTop: 20,
  paddingRight: 0,
  paddingBottom: 8,
  paddingLeft: 0,
  color: 'black',
  fontSize: 15,
  fontWeight: 'normal'
};
const Input = (_ref, ref) => {
  let {
    minHeight,
    maxHeight,
    marginTop,
    marginRight,
    marginBottom = defaultProps.marginBottom,
    marginLeft,
    paddingTop = defaultProps.paddingTop,
    paddingRight = defaultProps.paddingRight,
    paddingBottom = defaultProps.paddingBottom,
    paddingLeft = defaultProps.paddingLeft,
    color = defaultProps.color,
    activeColor,
    fontFamily,
    fontSize = defaultProps.fontSize,
    fontWeight = defaultProps.fontWeight,
    label,
    labelDuration,
    labelColor,
    labelActiveTop,
    labelActiveColor,
    labelActiveScale,
    placeholder,
    placeholderColor,
    underlineDuration,
    underlineHeight,
    underlineColor,
    underlineActiveColor,
    underlineActiveHeight,
    error,
    errorColor = errorDefaultProps.errorColor,
    errorPaddingTop,
    errorFontSize,
    ...props
  } = _ref;
  const [value, setValue] = useState('');
  const [focused, setFocused] = useState(false);
  const [height, setHeight] = useState(fontSize * 1.5);
  const getValue = props.value != null ? props.value : value;
  const hasValue = Boolean(getValue && getValue.length > 0);
  const labelProps = {
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    activeColor,
    fontFamily,
    fontSize,
    fontWeight,
    label,
    labelDuration,
    labelColor,
    labelActiveTop,
    labelActiveColor,
    labelActiveScale,
    focused,
    hasValue,
    error,
    errorColor
  };
  const placeholderProps = {
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    fontFamily,
    fontSize,
    fontWeight,
    placeholder,
    placeholderColor,
    focused,
    hasValue
  };
  const underlineProps = {
    activeColor,
    underlineDuration,
    underlineHeight,
    underlineColor,
    underlineActiveColor,
    underlineActiveHeight,
    focused,
    error,
    errorColor
  };
  const containerStyle = {
    marginTop,
    marginRight,
    marginBottom,
    marginLeft
  };
  let getHeight = height;
  if (props.multiline && props.height) {
    // Disable autogrow if height prop
    getHeight = props.height;
  }
  const inputStyle = {
    minHeight,
    maxHeight,
    paddingTop,
    paddingRight,
    paddingBottom,
    paddingLeft,
    color,
    fontFamily,
    fontSize,
    fontWeight,
    textAlign: I18nManager.isRTL ? 'right' : 'left',
    ...Platform.select({
      ios: {
        height: paddingTop + paddingBottom + (props.multiline ? getHeight : fontSize * 1.5)
      },
      android: {
        height: props.multiline ? getHeight : fontSize * 1.5 + paddingTop + paddingBottom,
        textAlignVertical: 'top'
      }
    })
  };
  const errorProps = {
    error,
    errorColor,
    errorPaddingTop,
    errorFontSize
  };
  return /*#__PURE__*/React.createElement(View, {
    style: containerStyle
  }, /*#__PURE__*/React.createElement(Label, labelProps), placeholder ? /*#__PURE__*/React.createElement(Placeholder, placeholderProps) : null, /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
    ref: ref,
    style: inputStyle,
    underlineColorAndroid: "transparent",
    onFocus: handleFocus,
    onBlur: handleBlur,
    onChangeText: handleChangeText,
    onContentSizeChange: handleContentSizeChange,
    value: getValue
  })), /*#__PURE__*/React.createElement(Underline, underlineProps), error ? /*#__PURE__*/React.createElement(ErrorHelper, errorProps) : null);
  function handleFocus(event) {
    setFocused(true);
    if (typeof props.onFocus === 'function') {
      props.onFocus(event);
    }
  }
  function handleBlur(event) {
    setFocused(false);
    if (typeof props.onBlur === 'function') {
      props.onBlur(event);
    }
  }
  function handleChangeText(text) {
    const {
      value
    } = props;

    // Make support of uncontrolled component
    if (value == null) {
      setValue(text);
    }
    if (typeof props.onChangeText === 'function') {
      props.onChangeText(text);
    }
  }
  function handleContentSizeChange(event) {
    const {
      height
    } = event.nativeEvent.contentSize;
    setHeight(Math.max(fontSize * 1.5, Math.ceil(height)));
    if (typeof props.onContentSizeChange === 'function') {
      props.onContentSizeChange(event);
    }
  }
};
export default /*#__PURE__*/React.forwardRef(Input);
//# sourceMappingURL=Input.js.map